from typing import List

from pywttr_models import base


class WeatherItem(base.WeatherItem):
    hourly: List[base.HourlyItem]


class Model(base.Model):
    current_condition: List[base.CurrentConditionItem]
    weather: List[WeatherItem]



from pywttr_models import (
    af,
    am,
    ar,
    base,
    be,
    bn,
    ca,
    da,
    de,
    el,
    en,
    et,
    fa,
    fr,
    hi,
    hu,
    ia,
    id,
    it,
    lt,
    mg,
    nb,
    nl,
    oc,
    pl,
    pt_br,
    ro,
    ru,
    ta,
    th,
    tr,
    uk,
    vi,
    zh_cn,
    zh_tw,
)

__all__ = (
    "af",
    "am",
    "ar",
    "base",
    "be",
    "bn",
    "ca",
    "da",
    "de",
    "el",
    "en",
    "et",
    "fa",
    "fr",
    "hi",
    "hu",
    "ia",
    "id",
    "it",
    "lt",
    "mg",
    "nb",
    "nl",
    "oc",
    "pl",
    "pt_br",
    "ro",
    "ru",
    "ta",
    "th",
    "tr",
    "uk",
    "vi",
    "zh_cn",
    "zh_tw",
)



from typing import List

from pywttr_models import base


class CurrentConditionItem(base.CurrentConditionItem):
    lang_ar: List[base.LangItem]


class HourlyItem(base.HourlyItem):
    lang_ar: List[base.LangItem]


class WeatherItem(base.WeatherItem):
    hourly: List[HourlyItem]


class Model(base.Model):
    current_condition: List[CurrentConditionItem]
    weather: List[WeatherItem]



from typing import List

from pydantic import Field

from pywttr_models import base


class CurrentConditionItem(base.CurrentConditionItem):
    lang_zh_cn: List[base.LangItem] = Field(..., alias="lang_zh-cn")


class HourlyItem(base.HourlyItem):
    lang_zh_cn: List[base.LangItem] = Field(..., alias="lang_zh-cn")


class WeatherItem(base.WeatherItem):
    hourly: List[HourlyItem]


class Model(base.Model):
    current_condition: List[CurrentConditionItem]
    weather: List[WeatherItem]
